"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = MultiWordHighlighter;
var _react = _interopRequireWildcard(require("react"));
var _linebreak = _interopRequireDefault(require("linebreak"));
var _reactNative = require("react-native");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
// @ts-ignore

function MultiWordHighlighter(props) {
  const {
    searchWords,
    textToHighlight,
    caseSensitive = false,
    viewContainerStyle = null,
    defaultHighlightTextStyle = null,
    nonMatchedStringTextStyle,
    replaceAllMatchedTextWith
  } = props;
  const words = (0, _react.useMemo)(() => {
    let arr = [];
    const breaker = new _linebreak.default(textToHighlight);
    let last = 0;
    let bk;
    while (bk = breaker.nextBreak()) {
      var word = textToHighlight.slice(last, bk.position);
      arr.push(word);
      last = bk.position;
    }
    return arr;
  }, [textToHighlight]);
  const wordToConfigMap = (0, _react.useMemo)(() => {
    let map = {};
    searchWords.forEach(searchWord => {
      let key = searchWord.word;
      if (!caseSensitive) {
        key = key.toLowerCase();
      }
      map[key] = searchWord;
    });
    return map;
  }, [searchWords, caseSensitive]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.viewContainerStyle, viewContainerStyle]
  }, words.map((w, idx) => {
    const text = w;
    let key = text.replace(/[^a-zA-Z0-9]/, '');
    if (!caseSensitive) {
      key = key.toLowerCase();
    }
    if (wordToConfigMap[key]) {
      var _wordToConfigMap$key, _wordToConfigMap$key2, _wordToConfigMap$key3, _wordToConfigMap$key4;
      return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        key: idx,
        style: [(_wordToConfigMap$key = wordToConfigMap[key]) !== null && _wordToConfigMap$key !== void 0 && _wordToConfigMap$key.textStyle ? (_wordToConfigMap$key2 = wordToConfigMap[key]) === null || _wordToConfigMap$key2 === void 0 ? void 0 : _wordToConfigMap$key2.textStyle : defaultHighlightTextStyle]
      }, (_wordToConfigMap$key3 = wordToConfigMap[key]) !== null && _wordToConfigMap$key3 !== void 0 && _wordToConfigMap$key3.replace ? text.replace(key, (_wordToConfigMap$key4 = wordToConfigMap[key]) === null || _wordToConfigMap$key4 === void 0 ? void 0 : _wordToConfigMap$key4.replace) : replaceAllMatchedTextWith ? text.replace(key, replaceAllMatchedTextWith) : text);
    } else {
      return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        key: idx,
        style: nonMatchedStringTextStyle ? nonMatchedStringTextStyle : null
      }, text);
    }
  }));
}
const styles = _reactNative.StyleSheet.create({
  viewContainerStyle: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
//# sourceMappingURL=MultiWordHighlighter.js.map