import React, { useMemo } from 'react';
// @ts-ignore
import LineBreaker from 'linebreak';
import { View, StyleSheet, Text } from 'react-native';
export default function MultiWordHighlighter(props) {
  const {
    searchWords,
    textToHighlight,
    caseSensitive = false,
    viewContainerStyle = null,
    defaultHighlightTextStyle = null,
    nonMatchedStringTextStyle,
    replaceAllMatchedTextWith
  } = props;
  const words = useMemo(() => {
    let arr = [];
    const breaker = new LineBreaker(textToHighlight);
    let last = 0;
    let bk;
    while (bk = breaker.nextBreak()) {
      var word = textToHighlight.slice(last, bk.position);
      arr.push(word);
      last = bk.position;
    }
    return arr;
  }, [textToHighlight]);
  const wordToConfigMap = useMemo(() => {
    let map = {};
    searchWords.forEach(searchWord => {
      let key = searchWord.word;
      if (!caseSensitive) {
        key = key.toLowerCase();
      }
      map[key] = searchWord;
    });
    return map;
  }, [searchWords, caseSensitive]);
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.viewContainerStyle, viewContainerStyle]
  }, words.map((w, idx) => {
    const text = w;
    let key = text.replace(/[^a-zA-Z0-9]/, '');
    if (!caseSensitive) {
      key = key.toLowerCase();
    }
    if (wordToConfigMap[key]) {
      var _wordToConfigMap$key, _wordToConfigMap$key2, _wordToConfigMap$key3, _wordToConfigMap$key4;
      return /*#__PURE__*/React.createElement(Text, {
        key: idx,
        style: [(_wordToConfigMap$key = wordToConfigMap[key]) !== null && _wordToConfigMap$key !== void 0 && _wordToConfigMap$key.textStyle ? (_wordToConfigMap$key2 = wordToConfigMap[key]) === null || _wordToConfigMap$key2 === void 0 ? void 0 : _wordToConfigMap$key2.textStyle : defaultHighlightTextStyle]
      }, (_wordToConfigMap$key3 = wordToConfigMap[key]) !== null && _wordToConfigMap$key3 !== void 0 && _wordToConfigMap$key3.replace ? text.replace(key, (_wordToConfigMap$key4 = wordToConfigMap[key]) === null || _wordToConfigMap$key4 === void 0 ? void 0 : _wordToConfigMap$key4.replace) : replaceAllMatchedTextWith ? text.replace(key, replaceAllMatchedTextWith) : text);
    } else {
      return /*#__PURE__*/React.createElement(Text, {
        key: idx,
        style: nonMatchedStringTextStyle ? nonMatchedStringTextStyle : null
      }, text);
    }
  }));
}
const styles = StyleSheet.create({
  viewContainerStyle: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
//# sourceMappingURL=MultiWordHighlighter.js.map